@@ -1,5 +1,13 @@
 # Copyright (c) 2020 Red Hat, Inc.
 
+if ! jq --version > /dev/null 2>&1; then
+  echo "Missing dependency: jq"
+  return
+elif ! oc version> /dev/null 2>&1; then
+  echo "Missing dependency: oc"
+  return
+fi
+
 OCM_NAMESPACE=open-cluster-management
 OCM_ROUTE=multicloud-console
 OCM_ADDRESS=https://`oc -n $OCM_NAMESPACE get route $OCM_ROUTE -o json | jq -r '.spec.host'`
@@ -15,8 +23,8 @@ oc patch OAuthClient multicloudingress --type json -p "[{\"op\": \"add\", \"path
 SERVICEACCT_TOKEN=$(oc whoami -t)
 API_SERVER_URL=$(oc whoami --show-server)
 headerUrl=$OCM_ADDRESS
-hcmUiApiUrl=$OCM_ADDRESS/multicloud/graphql
-searchApiUrl=$OCM_ADDRESS/multicloud/search/graphql
+hcmUiApiUrl=$OCM_ADDRESS/multicloud/applications/graphql
+searchApiUrl=$OCM_ADDRESS/multicloud/applications/search/graphql
 
 echo
 echo '"env": {'
