@@ -120,13 +120,9 @@ export default class LinkHelper {
   };
 
   moveLinks = (transition, currentZoom) => {
-    // don't move looped dragged links
     let links = this.svg
       .select('g.links')
       .selectAll('g.link')
-      .filter(({ layout: { source: { dragged } } }) => {
-        return !dragged
-      })
       .attr('transform', currentZoom)
 
     const isHidden = layout => {
@@ -530,7 +526,10 @@ export const counterZoomLinks = (svg, currentZoom, showLineLabels) => {
     if (showLineLabels) {
       const fontSize = counterZoom(currentZoom.k, 0.2, 0.85, 10, 20)
       const labels = svg.select('g.links').selectAll('g.label')
-      labels.selectAll('text.linkText').style('font-size', fontSize + 'px')
+      labels
+        .selectAll('text.linkText')
+        .style('font-size', fontSize + 'px')
+        .attr('dy', -2)
     }
   }
 }
