@@ -53,12 +53,9 @@ module.exports = {
         test: [/\.jsx$/, /\.js$/],
         exclude: [
           {
-            test: [
-              /\.scss$/,
-              path.resolve(__dirname, './node_modules'),
-            ],
+            test: [/\.scss$/, path.resolve(__dirname, "./node_modules")],
             exclude: [
-              path.resolve(__dirname, './node_modules/fuse.js'),
+              path.resolve(__dirname, "./node_modules/fuse.js")
               //path.resolve(__dirname, './node_modules/temptifly'),
             ]
           }
@@ -105,12 +102,12 @@ module.exports = {
         loader: "file-loader?name=fonts/[name].[ext]"
       },
       {
-      test: /\.css$/,
+        test: /\.css$/,
         include: [
-         path.resolve(__dirname, './node_modules/temptifly'),
-         path.resolve(__dirname, './node_modules/monaco-editor'),
-         path.resolve(__dirname, '../temptifly/node_modules/monaco-editor/'),
-         path.resolve(__dirname, './node_modules/@open-cluster-management/ui-components')
+          path.resolve(__dirname, "./node_modules/temptifly"),
+          path.resolve(__dirname, "./node_modules/monaco-editor"),
+          path.resolve(__dirname, "../temptifly/node_modules/monaco-editor/"),
+          path.resolve(__dirname, "./node_modules/@stolostron/ui-components")
         ],
         use: ["style-loader", "css-loader"]
       },
